| Copyright | Will Thompson and Iñaki García Etxebarria |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Vte.Constants
Description
Synopsis
- pattern TEST_FLAGS_NONE :: Word64
- pattern TEST_FLAGS_ALL :: Word64
- pattern TERMPROP_XTERM_TITLE :: Text
- pattern TERMPROP_SHELL_PREEXEC :: Text
- pattern TERMPROP_SHELL_PRECMD :: Text
- pattern TERMPROP_SHELL_POSTEXEC :: Text
- pattern TERMPROP_PROGRESS_VALUE :: Text
- pattern TERMPROP_PROGRESS_HINT :: Text
- pattern TERMPROP_NAME_PREFIX :: Text
- pattern TERMPROP_ICON_IMAGE :: Text
- pattern TERMPROP_ICON_COLOR :: Text
- pattern TERMPROP_CURRENT_FILE_URI :: Text
- pattern TERMPROP_CURRENT_DIRECTORY_URI :: Text
- pattern TERMPROP_CONTAINER_UID :: Text
- pattern TERMPROP_CONTAINER_RUNTIME :: Text
- pattern TERMPROP_CONTAINER_NAME :: Text
- pattern SPAWN_REQUIRE_SYSTEMD_SCOPE :: Int32
- pattern SPAWN_NO_SYSTEMD_SCOPE :: Int32
- pattern SPAWN_NO_PARENT_ENVV :: Int32
- pattern REGEX_FLAGS_DEFAULT :: Int32
- pattern MINOR_VERSION :: Int32
- pattern MICRO_VERSION :: Int32
- pattern MAJOR_VERSION :: Int32
Documentation
pattern TEST_FLAGS_NONE :: Word64 Source #
No description available in the introspection data.
pattern TEST_FLAGS_ALL :: Word64 Source #
No description available in the introspection data.
pattern TERMPROP_XTERM_TITLE :: Text Source #
A PropertyTypeString termprop that stores the xterm window title
as set by OSC 0 and OSC 2.
Use this with terminalGetTermpropString instead of using
terminalGetWindowTitle.
Note that this termprop is not settable via the termprop OSC.
Since: 0.78
pattern TERMPROP_SHELL_PREEXEC :: Text Source #
A PropertyTypeValueless termprop that signals that the shell
is preparing to execute the command entered at the prompt.
Since: 0.78
pattern TERMPROP_SHELL_PRECMD :: Text Source #
A PropertyTypeValueless termprop that signals that the shell
is going to prompt.
Since: 0.78
pattern TERMPROP_SHELL_POSTEXEC :: Text Source #
An ephemeral PropertyTypeUint termprop that signals that the shell
has executed the commands entered at the prompt and these commands
have returned. The termprop value is the exit code.
Since: 0.78
pattern TERMPROP_PROGRESS_VALUE :: Text Source #
A PropertyTypeUint termprop that stores the progress of the running
command as a value between 0 and 100.
Note that this termprop cannot be set by the termprop OSC, but instead only by OSC 9 ; 4 (ConEmu progress).
Since: 0.80
pattern TERMPROP_PROGRESS_HINT :: Text Source #
A PropertyTypeInt termprop that stores a hint how to interpret
the TERMPROP_PROGRESS_VALUE termprop value. If set, this
termprop's value will be from the ProgressHint enumeration.
An unset termprop should be treated as if it had value
ProgressHintActive if the TERMPROP_PROGRESS_VALUE
termprop has a value
Note that this termprop never will have the value
ProgressHintInactive.
The value of this termprop should be ignored unless the
TERMPROP_PROGRESS_VALUE termprop has a value.
Note that this termprop cannot be set by the termprop OSC, but instead only by OSC 9 ; 4 (ConEmu progress).
Since: 0.80
pattern TERMPROP_NAME_PREFIX :: Text Source #
The string prefix that any termprop's name must start with to be installed
by installTermprop.
Since: 0.78
pattern TERMPROP_ICON_IMAGE :: Text Source #
A PropertyTypeImage termprop to specify an image for use
as a favicon.
Applications should prefer to use this termprop, if set, over
the TERMPROP_ICON_COLOR color.
Note that in this vte version, this termprop is always unset.
Since: 0.80
pattern TERMPROP_ICON_COLOR :: Text Source #
No description available in the introspection data.
pattern TERMPROP_CURRENT_FILE_URI :: Text Source #
A PropertyTypeUri termprop that stores the current file URI
as set by OSC 6.
Use this with terminalRefTermpropUri instead of using
terminalGetCurrentFileUri.
Note that this termprop is not settable via the termprop OSC.
Since: 0.78
pattern TERMPROP_CURRENT_DIRECTORY_URI :: Text Source #
A PropertyTypeUri termprop that stores the current directory
URI as set by OSC 7.
Use this with terminalRefTermpropUri instead of using
terminalGetCurrentDirectoryUri.
Note that this termprop is not settable via the termprop OSC.
Since: 0.78
pattern TERMPROP_CONTAINER_UID :: Text Source #
A PropertyTypeUint termprop that stores the user ID of the
container.
Since: 0.78
pattern TERMPROP_CONTAINER_RUNTIME :: Text Source #
A PropertyTypeString termprop that stores the runtime of the
container.
Since: 0.78
pattern TERMPROP_CONTAINER_NAME :: Text Source #
A PropertyTypeString termprop that stores the name of the
container.
Since: 0.78
pattern SPAWN_REQUIRE_SYSTEMD_SCOPE :: Int32 Source #
Use this as a spawn flag (together with flags from SpawnFlags) in
ptySpawnAsync.
Requires ptySpawnAsync etc. to move the newly created child
process to a systemd user scope; if that fails, the whole spawn fails.
This is supported on Linux only.
Since: 0.60
pattern SPAWN_NO_SYSTEMD_SCOPE :: Int32 Source #
Use this as a spawn flag (together with flags from SpawnFlags) in
ptySpawnAsync.
Prevents ptySpawnAsync etc. from moving the newly created child
process to a systemd user scope.
Since: 0.60
pattern SPAWN_NO_PARENT_ENVV :: Int32 Source #
Use this as a spawn flag (together with flags from SpawnFlags) in
ptySpawnAsync.
Normally, the spawned process inherits the environment from the parent
process; when this flag is used, only the environment variables passed
to ptySpawnAsync etc. are passed to the child process.
pattern REGEX_FLAGS_DEFAULT :: Int32 Source #
No description available in the introspection data.
pattern MINOR_VERSION :: Int32 Source #
The minor version number of the VTE library (e.g. in version 3.1.4 this is 1).
pattern MICRO_VERSION :: Int32 Source #
The micro version number of the VTE library (e.g. in version 3.1.4 this is 4).
pattern MAJOR_VERSION :: Int32 Source #
The major version number of the VTE library (e.g. in version 3.1.4 this is 3).